autowisp.tests.test_fit_source_extracted_psf_map module — AutoWISP documentation

# autowisp.tests.test_fit_source_extracted_psf_map module

## Class Inheritance Diagram

Define test case for the fit_source_extracted_psf_map step.

class autowisp.tests.test_fit_source_extracted_psf_map.TestFitSourceExtractedPSFMap(methodName='runTest')

  Bases: `H5TestCase`

  Tests of the fit_source_extracted_psf_map step.

  test_fit_source_extracted_psf_map()

    Run the fit_source_extracted_psf_map step and check the outputs.